@@ -29,7 +29,7 @@ class Pg:
 
     
     async def ncfetchs(self):
-        content = await self.pool.fetch(f"SELECT * FROM {self.table})
+        content = await self.pool.fetch(f"SELECT * FROM {self.table}")
  
         return content
 
